# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class ThreadServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def DescribeThread(self, request, **kwargs):
        path = "/thread"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.DescribeThreadOutput"),
            **kwargs,
        )

    def VoteThread(self, request, **kwargs):
        path = "/thread/vote"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.VoteThreadOutput"),
            **kwargs,
        )

    def UpdateSubscription(self, request, **kwargs):
        path = "/thread/subscription"

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.UpdateSubscriptionOutput"),
            **kwargs,
        )

    def DescribeMessage(self, request, **kwargs):
        path = "/thread/messages/"+urllib.parse.quote(request.message_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.message_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.DescribeMessageOutput"),
            **kwargs,
        )

    def ListMessages(self, request, **kwargs):
        path = "/thread/messages"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.ListMessagesOutput"),
            **kwargs,
        )

    def PostMessage(self, request, **kwargs):
        path = "/thread/messages"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.PostMessageOutput"),
            **kwargs,
        )

    def UpdateMessage(self, request, **kwargs):
        path = "/thread/messages/"+urllib.parse.quote(request.message_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.message_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.UpdateMessageOutput"),
            **kwargs,
        )

    def DeleteMessage(self, request, **kwargs):
        path = "/messages/"+urllib.parse.quote(request.message_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.message_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.DeleteMessageOutput"),
            **kwargs,
        )

    def VoteMessage(self, request, **kwargs):
        path = "/messages/"+urllib.parse.quote(request.message_id)+"/vote"

        # Cleanup URL parameters to avoid any ambiguity
        request.message_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.VoteMessageOutput"),
            **kwargs,
        )

    def ListMessageChanges(self, request, **kwargs):
        path = "/messages/"+urllib.parse.quote(request.message_id)+"/changes"

        # Cleanup URL parameters to avoid any ambiguity
        request.message_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.ListMessageChangesOutput"),
            **kwargs,
        )




from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.atlas import code_template_pb2 as _code_template_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateCodeTemplateInput(_message.Message):
    __slots__ = ("template",)
    TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    template: _code_template_pb2.Template
    def __init__(self, template: _Optional[_Union[_code_template_pb2.Template, _Mapping]] = ...) -> None: ...

class CreateCodeTemplateOutput(_message.Message):
    __slots__ = ("template_id",)
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    template_id: str
    def __init__(self, template_id: _Optional[str] = ...) -> None: ...

class UpdateCodeTemplateInput(_message.Message):
    __slots__ = ("template_id", "template")
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    template_id: str
    template: _code_template_pb2.Template
    def __init__(self, template_id: _Optional[str] = ..., template: _Optional[_Union[_code_template_pb2.Template, _Mapping]] = ...) -> None: ...

class UpdateCodeTemplateOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteCodeTemplateInput(_message.Message):
    __slots__ = ("template_id",)
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    template_id: str
    def __init__(self, template_id: _Optional[str] = ...) -> None: ...

class DeleteCodeTemplateOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListCodeTemplatesInput(_message.Message):
    __slots__ = ("offset", "size", "version")
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    version: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., version: _Optional[int] = ...) -> None: ...

class ListCodeTemplatesOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_code_template_pb2.Template]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_code_template_pb2.Template, _Mapping]]] = ...) -> None: ...

class DescribeCodeTemplateInput(_message.Message):
    __slots__ = ("template_id", "version")
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    template_id: str
    version: int
    def __init__(self, template_id: _Optional[str] = ..., version: _Optional[int] = ...) -> None: ...

class DescribeCodeTemplateOutput(_message.Message):
    __slots__ = ("template",)
    TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    template: _code_template_pb2.Template
    def __init__(self, template: _Optional[_Union[_code_template_pb2.Template, _Mapping]] = ...) -> None: ...

class LookupCodeTemplateInput(_message.Message):
    __slots__ = ("runtime",)
    RUNTIME_FIELD_NUMBER: _ClassVar[int]
    runtime: str
    def __init__(self, runtime: _Optional[str] = ...) -> None: ...

class LookupCodeTemplateOutput(_message.Message):
    __slots__ = ("template",)
    TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    template: _code_template_pb2.Template
    def __init__(self, template: _Optional[_Union[_code_template_pb2.Template, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/community/member_user.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/community/member_user.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.community import email_type_pb2 as eolymp_dot_community_dot_email__type__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/community/member_user.proto\x12\x10\x65olymp.community\x1a!eolymp/community/email_type.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf0\x04\n\x04User\x12\x0e\n\x06issuer\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\x10\n\x08nickname\x18\n \x01(\t\x12\x1f\n\x17nickname_change_timeout\x18\x0b \x01(\r\x12-\n\x07\x61liases\x18\r \x03(\x0b\x32\x1c.eolymp.community.User.Alias\x12\r\n\x05\x65mail\x18\x14 \x01(\t\x12\x16\n\x0e\x65mail_verified\x18\x15 \x01(\x08\x12\x18\n\x10\x65mail_restricted\x18\x0c \x01(\x08\x12\x38\n\x13\x65mail_subscriptions\x18\x16 \x03(\x0e\x32\x1b.eolymp.community.EmailType\x12\x10\n\x08password\x18\x1e \x01(\t\x12\x14\n\x0cpassword_age\x18\x1f \x01(\r\x12\x0c\n\x04name\x18( \x01(\t\x12\x0f\n\x07picture\x18\x32 \x01(\t\x12,\n\x08\x62irthday\x18< \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x63ountry\x18\x46 \x01(\t\x12\x0c\n\x04\x63ity\x18I \x01(\t\x12\x0f\n\x07team_id\x18\x64 \x01(\t\x12\x38\n\x0bpreferences\x18\xa0\x06 \x01(\x0b\x32\".eolymp.community.User.Preferences\x1a@\n\x0bPreferences\x12\x0e\n\x06locale\x18\x01 \x01(\t\x12\x10\n\x08timezone\x18\x02 \x01(\t\x12\x0f\n\x07runtime\x18\n \x01(\t\x1aI\n\x05\x41lias\x12\x10\n\x08nickname\x18\x01 \x01(\t\x12.\n\nchanged_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.member_user_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _globals['_USER']._serialized_start=125
  _globals['_USER']._serialized_end=749
  _globals['_USER_PREFERENCES']._serialized_start=610
  _globals['_USER_PREFERENCES']._serialized_end=674
  _globals['_USER_ALIAS']._serialized_start=676
  _globals['_USER_ALIAS']._serialized_end=749
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/community/rating_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/community/rating_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import namespace_pb2 as eolymp_dot_annotations_dot_namespace__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.community import rating_point_pb2 as eolymp_dot_community_dot_rating__point__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%eolymp/community/rating_service.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/namespace.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a#eolymp/community/rating_point.proto\"R\n\x0eSetRatingInput\x12\x11\n\trating_id\x18\x01 \x01(\t\x12-\n\x06rating\x18\x02 \x01(\x0b\x32\x1d.eolymp.community.RatingPoint\"$\n\x0fSetRatingOutput\x12\x11\n\trating_id\x18\x01 \x01(\t\"T\n\x11\x44\x65leteRatingInput\x12\x11\n\trating_id\x18\x02 \x01(\t\x12,\n\x05point\x18\x03 \x01(\x0b\x32\x1d.eolymp.community.RatingPoint\"\x14\n\x12\x44\x65leteRatingOutput2\xe5\x02\n\rRatingService\x12\x8e\x01\n\tSetRating\x12 .eolymp.community.SetRatingInput\x1a!.eolymp.community.SetRatingOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\x82\xd3\xe4\x93\x02\t\"\x07/rating\x12\xa3\x01\n\x0c\x44\x65leteRating\x12#.eolymp.community.DeleteRatingInput\x1a$.eolymp.community.DeleteRatingOutput\"H\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\x82\xd3\xe4\x93\x02\x15*\x13/rating/{rating_id}\x1a\x1d\x82\xf0\xf0\xe4\x01\x17\x65olymp.community.MemberB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.rating_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _globals['_RATINGSERVICE']._loaded_options = None
  _globals['_RATINGSERVICE']._serialized_options = b'\202\360\360\344\001\027eolymp.community.Member'
  _globals['_RATINGSERVICE'].methods_by_name['SetRating']._loaded_options = None
  _globals['_RATINGSERVICE'].methods_by_name['SetRating']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\032\212\343\n\026community:member:write\202\323\344\223\002\t\"\007/rating'
  _globals['_RATINGSERVICE'].methods_by_name['DeleteRating']._loaded_options = None
  _globals['_RATINGSERVICE'].methods_by_name['DeleteRating']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\032\212\343\n\026community:member:write\202\323\344\223\002\025*\023/rating/{rating_id}'
  _globals['_SETRATINGINPUT']._serialized_start=231
  _globals['_SETRATINGINPUT']._serialized_end=313
  _globals['_SETRATINGOUTPUT']._serialized_start=315
  _globals['_SETRATINGOUTPUT']._serialized_end=351
  _globals['_DELETERATINGINPUT']._serialized_start=353
  _globals['_DELETERATINGINPUT']._serialized_end=437
  _globals['_DELETERATINGOUTPUT']._serialized_start=439
  _globals['_DELETERATINGOUTPUT']._serialized_end=459
  _globals['_RATINGSERVICE']._serialized_start=462
  _globals['_RATINGSERVICE']._serialized_end=819
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/community/credit.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/community/credit.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/community/credit.proto\x12\x10\x65olymp.community\x1a\x1fgoogle/protobuf/timestamp.proto\"\xda\x02\n\x06\x43redit\x1a\xe4\x01\n\x05Grant\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\treference\x18\x02 \x01(\t\x12\x0c\n\x04note\x18\x03 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x14 \x01(\x08\x12\x0f\n\x07revoked\x18\x15 \x01(\x08\x12\x14\n\x0ctotal_amount\x18\x04 \x01(\r\x12\x17\n\x0fredeemed_amount\x18\x05 \x01(\r\x12.\n\ngranted_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nexpires_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1ai\n\x0bTransaction\x12\n\n\x02id\x18\x01 \x01(\t\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07summary\x18\x03 \x01(\t\x12\x0e\n\x06\x61mount\x18\x04 \x01(\rB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.credit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _globals['_CREDIT']._serialized_start=85
  _globals['_CREDIT']._serialized_end=431
  _globals['_CREDIT_GRANT']._serialized_start=96
  _globals['_CREDIT_GRANT']._serialized_end=324
  _globals['_CREDIT_TRANSACTION']._serialized_start=326
  _globals['_CREDIT_TRANSACTION']._serialized_end=431
# @@protoc_insertion_point(module_scope)



import datetime

from eolymp.community import attribute_pb2 as _attribute_pb2
from eolymp.community import member_ghost_pb2 as _member_ghost_pb2
from eolymp.community import member_team_pb2 as _member_team_pb2
from eolymp.community import member_user_pb2 as _member_user_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Member(_message.Message):
    __slots__ = ("id", "url", "external_ref", "display_name", "rank", "rank_lower", "rating", "level", "inactive", "incomplete", "unofficial", "secret", "created_at", "seated_at", "active_at", "user", "team", "ghost", "stats", "groups", "attributes", "metadata")
    class Extra(_message.Message):
        __slots__ = ()
        class Field(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            NO_EXTRA: _ClassVar[Member.Extra.Field]
            STATS: _ClassVar[Member.Extra.Field]
            GROUPS: _ClassVar[Member.Extra.Field]
            ATTRIBUTES: _ClassVar[Member.Extra.Field]
            METADATA: _ClassVar[Member.Extra.Field]
        NO_EXTRA: Member.Extra.Field
        STATS: Member.Extra.Field
        GROUPS: Member.Extra.Field
        ATTRIBUTES: Member.Extra.Field
        METADATA: Member.Extra.Field
        def __init__(self) -> None: ...
    class Patch(_message.Message):
        __slots__ = ()
        class Field(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNKNOWN: _ClassVar[Member.Patch.Field]
            EXTERNAL_REF: _ClassVar[Member.Patch.Field]
            INACTIVE: _ClassVar[Member.Patch.Field]
            UNOFFICIAL: _ClassVar[Member.Patch.Field]
            GROUPS: _ClassVar[Member.Patch.Field]
            GROUPS_ADD: _ClassVar[Member.Patch.Field]
            GROUPS_REMOVE: _ClassVar[Member.Patch.Field]
            ACCOUNT: _ClassVar[Member.Patch.Field]
            USER_NICKNAME: _ClassVar[Member.Patch.Field]
            USER_EMAIL: _ClassVar[Member.Patch.Field]
            USER_PASSWORD: _ClassVar[Member.Patch.Field]
            USER_NAME: _ClassVar[Member.Patch.Field]
            USER_PICTURE: _ClassVar[Member.Patch.Field]
            USER_BIRTHDAY: _ClassVar[Member.Patch.Field]
            USER_COUNTRY: _ClassVar[Member.Patch.Field]
            USER_CITY: _ClassVar[Member.Patch.Field]
            USER_PREFERENCES: _ClassVar[Member.Patch.Field]
            USER_PREFERENCES_LOCALE: _ClassVar[Member.Patch.Field]
            USER_PREFERENCES_TIMEZONE: _ClassVar[Member.Patch.Field]
            USER_PREFERENCES_RUNTIME: _ClassVar[Member.Patch.Field]
            USER_EMAIL_SUBSCRIPTIONS: _ClassVar[Member.Patch.Field]
            TEAM_NAME: _ClassVar[Member.Patch.Field]
            GHOST_NAME: _ClassVar[Member.Patch.Field]
            ATTRIBUTES: _ClassVar[Member.Patch.Field]
            METADATA: _ClassVar[Member.Patch.Field]
        UNKNOWN: Member.Patch.Field
        EXTERNAL_REF: Member.Patch.Field
        INACTIVE: Member.Patch.Field
        UNOFFICIAL: Member.Patch.Field
        GROUPS: Member.Patch.Field
        GROUPS_ADD: Member.Patch.Field
        GROUPS_REMOVE: Member.Patch.Field
        ACCOUNT: Member.Patch.Field
        USER_NICKNAME: Member.Patch.Field
        USER_EMAIL: Member.Patch.Field
        USER_PASSWORD: Member.Patch.Field
        USER_NAME: Member.Patch.Field
        USER_PICTURE: Member.Patch.Field
        USER_BIRTHDAY: Member.Patch.Field
        USER_COUNTRY: Member.Patch.Field
        USER_CITY: Member.Patch.Field
        USER_PREFERENCES: Member.Patch.Field
        USER_PREFERENCES_LOCALE: Member.Patch.Field
        USER_PREFERENCES_TIMEZONE: Member.Patch.Field
        USER_PREFERENCES_RUNTIME: Member.Patch.Field
        USER_EMAIL_SUBSCRIPTIONS: Member.Patch.Field
        TEAM_NAME: Member.Patch.Field
        GHOST_NAME: Member.Patch.Field
        ATTRIBUTES: Member.Patch.Field
        METADATA: Member.Patch.Field
        def __init__(self) -> None: ...
    class Stats(_message.Message):
        __slots__ = ("streak", "problems_solved", "submissions_accepted", "submissions_total")
        STREAK_FIELD_NUMBER: _ClassVar[int]
        PROBLEMS_SOLVED_FIELD_NUMBER: _ClassVar[int]
        SUBMISSIONS_ACCEPTED_FIELD_NUMBER: _ClassVar[int]
        SUBMISSIONS_TOTAL_FIELD_NUMBER: _ClassVar[int]
        streak: int
        problems_solved: int
        submissions_accepted: int
        submissions_total: int
        def __init__(self, streak: _Optional[int] = ..., problems_solved: _Optional[int] = ..., submissions_accepted: _Optional[int] = ..., submissions_total: _Optional[int] = ...) -> None: ...
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_REF_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    RANK_FIELD_NUMBER: _ClassVar[int]
    RANK_LOWER_FIELD_NUMBER: _ClassVar[int]
    RATING_FIELD_NUMBER: _ClassVar[int]
    LEVEL_FIELD_NUMBER: _ClassVar[int]
    INACTIVE_FIELD_NUMBER: _ClassVar[int]
    INCOMPLETE_FIELD_NUMBER: _ClassVar[int]
    UNOFFICIAL_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    SEATED_AT_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_AT_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    TEAM_FIELD_NUMBER: _ClassVar[int]
    GHOST_FIELD_NUMBER: _ClassVar[int]
    STATS_FIELD_NUMBER: _ClassVar[int]
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    id: str
    url: str
    external_ref: str
    display_name: str
    rank: int
    rank_lower: int
    rating: int
    level: int
    inactive: bool
    incomplete: bool
    unofficial: bool
    secret: bool
    created_at: _timestamp_pb2.Timestamp
    seated_at: _timestamp_pb2.Timestamp
    active_at: _timestamp_pb2.Timestamp
    user: _member_user_pb2.User
    team: _member_team_pb2.Team
    ghost: _member_ghost_pb2.Ghost
    stats: Member.Stats
    groups: _containers.RepeatedScalarFieldContainer[str]
    attributes: _containers.RepeatedCompositeFieldContainer[_attribute_pb2.Attribute.Value]
    metadata: _containers.ScalarMap[str, str]
    def __init__(self, id: _Optional[str] = ..., url: _Optional[str] = ..., external_ref: _Optional[str] = ..., display_name: _Optional[str] = ..., rank: _Optional[int] = ..., rank_lower: _Optional[int] = ..., rating: _Optional[int] = ..., level: _Optional[int] = ..., inactive: bool = ..., incomplete: bool = ..., unofficial: bool = ..., secret: bool = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., seated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., active_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., user: _Optional[_Union[_member_user_pb2.User, _Mapping]] = ..., team: _Optional[_Union[_member_team_pb2.Team, _Mapping]] = ..., ghost: _Optional[_Union[_member_ghost_pb2.Ghost, _Mapping]] = ..., stats: _Optional[_Union[Member.Stats, _Mapping]] = ..., groups: _Optional[_Iterable[str]] = ..., attributes: _Optional[_Iterable[_Union[_attribute_pb2.Attribute.Value, _Mapping]]] = ..., metadata: _Optional[_Mapping[str, str]] = ...) -> None: ...



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Credit(_message.Message):
    __slots__ = ()
    class Grant(_message.Message):
        __slots__ = ("id", "reference", "note", "active", "revoked", "total_amount", "redeemed_amount", "granted_at", "expires_at")
        ID_FIELD_NUMBER: _ClassVar[int]
        REFERENCE_FIELD_NUMBER: _ClassVar[int]
        NOTE_FIELD_NUMBER: _ClassVar[int]
        ACTIVE_FIELD_NUMBER: _ClassVar[int]
        REVOKED_FIELD_NUMBER: _ClassVar[int]
        TOTAL_AMOUNT_FIELD_NUMBER: _ClassVar[int]
        REDEEMED_AMOUNT_FIELD_NUMBER: _ClassVar[int]
        GRANTED_AT_FIELD_NUMBER: _ClassVar[int]
        EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
        id: str
        reference: str
        note: str
        active: bool
        revoked: bool
        total_amount: int
        redeemed_amount: int
        granted_at: _timestamp_pb2.Timestamp
        expires_at: _timestamp_pb2.Timestamp
        def __init__(self, id: _Optional[str] = ..., reference: _Optional[str] = ..., note: _Optional[str] = ..., active: bool = ..., revoked: bool = ..., total_amount: _Optional[int] = ..., redeemed_amount: _Optional[int] = ..., granted_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., expires_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
    class Transaction(_message.Message):
        __slots__ = ("id", "timestamp", "summary", "amount")
        ID_FIELD_NUMBER: _ClassVar[int]
        TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
        SUMMARY_FIELD_NUMBER: _ClassVar[int]
        AMOUNT_FIELD_NUMBER: _ClassVar[int]
        id: str
        timestamp: _timestamp_pb2.Timestamp
        summary: str
        amount: int
        def __init__(self, id: _Optional[str] = ..., timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., summary: _Optional[str] = ..., amount: _Optional[int] = ...) -> None: ...
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/annotations/mcp.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/annotations/mcp.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/annotations/mcp.proto\x12\neolymp.api\x1a google/protobuf/descriptor.proto\"N\n\x03MCP\x1aG\n\x04Tool\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1c\n\x14require_confirmation\x18\x03 \x01(\x08:I\n\x08mcp_tool\x12\x1e.google.protobuf.MethodOptions\x18\x81\x8e\xce\x1c \x01(\x0b\x32\x14.eolymp.api.MCP.Tool:<\n\x0emcp_value_desc\x12!.google.protobuf.EnumValueOptions\x18\x83\x8e\xce\x1c \x01(\t:8\n\x0emcp_field_desc\x12\x1d.google.protobuf.FieldOptions\x18\x84\x8e\xce\x1c \x01(\t:3\n\tread_only\x12\x1d.google.protobuf.FieldOptions\x18\x85\x8e\xce\x1c \x01(\x08\x42\x39Z7github.com/eolymp/go-sdk/eolymp/annotations;annotationsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.annotations.mcp_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/eolymp/go-sdk/eolymp/annotations;annotations'
  _globals['_MCP']._serialized_start=78
  _globals['_MCP']._serialized_end=156
  _globals['_MCP_TOOL']._serialized_start=85
  _globals['_MCP_TOOL']._serialized_end=156
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/content/translation_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/content/translation_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import namespace_pb2 as eolymp_dot_annotations_dot_namespace__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(eolymp/content/translation_service.proto\x12\x0e\x65olymp.content\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/namespace.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x18\x65olymp/ecm/content.proto\"=\n\x15TranslateContentInput\x12$\n\x07\x63ontent\x18\x01 \x01(\x0b\x32\x13.eolymp.ecm.Content\"B\n\x16TranslateContentOutput\x12(\n\x0btranslation\x18\x01 \x01(\x0b\x32\x13.eolymp.ecm.Content2\xbe\x01\n\x10TranslateService\x12\x8c\x01\n\x10TranslateContent\x12%.eolymp.content.TranslateContentInput\x1a&.eolymp.content.TranslateContentOutput\")\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x14\"\x12/content:translate\x1a\x1b\x82\xf0\xf0\xe4\x01\x15\x65olymp.universe.SpaceB1Z/github.com/eolymp/go-sdk/eolymp/content;contentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.content.translation_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/content;content'
  _globals['_TRANSLATESERVICE']._loaded_options = None
  _globals['_TRANSLATESERVICE']._serialized_options = b'\202\360\360\344\001\025eolymp.universe.Space'
  _globals['_TRANSLATESERVICE'].methods_by_name['TranslateContent']._loaded_options = None
  _globals['_TRANSLATESERVICE'].methods_by_name['TranslateContent']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\024\"\022/content:translate'
  _globals['_TRANSLATECONTENTINPUT']._serialized_start=189
  _globals['_TRANSLATECONTENTINPUT']._serialized_end=250
  _globals['_TRANSLATECONTENTOUTPUT']._serialized_start=252
  _globals['_TRANSLATECONTENTOUTPUT']._serialized_end=318
  _globals['_TRANSLATESERVICE']._serialized_start=321
  _globals['_TRANSLATESERVICE']._serialized_end=511
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/testing_checker.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/atlas/testing_checker.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import checker_pb2 as eolymp_dot_executor_dot_checker__pb2
from eolymp.executor import file_pb2 as eolymp_dot_executor_dot_file__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/atlas/testing_checker.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/executor/checker.proto\x1a\x1a\x65olymp/executor/file.proto\"\xe5\x01\n\x07\x43hecker\x12\x12\n\nversion_id\x18\x0b \x01(\t\x12\x0e\n\x06secret\x18\x07 \x01(\x08\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.eolymp.executor.Checker.Type\x12\x0f\n\x07runtime\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\x12$\n\x05\x66iles\x18\n \x03(\x0b\x32\x15.eolymp.executor.File\x12\x11\n\tprecision\x18\x04 \x01(\x05\x12\x16\n\x0e\x63\x61se_sensitive\x18\x05 \x01(\x08\x12\x17\n\x0forder_sensitive\x18\x06 \x01(\x08\x42-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.testing_checker_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_CHECKER']._serialized_start=112
  _globals['_CHECKER']._serialized_end=341
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/content/content_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/content/content_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import namespace_pb2 as eolymp_dot_annotations_dot_namespace__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.content import content_fragment_pb2 as eolymp_dot_content_dot_content__fragment__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/content/content_service.proto\x12\x0e\x65olymp.content\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/namespace.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a%eolymp/content/content_fragment.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"x\n\x14\x46ragmentChangedEvent\x12\r\n\x05scope\x18\n \x01(\t\x12(\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x18.eolymp.content.Fragment\x12\'\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x18.eolymp.content.Fragment\"\xa1\x01\n\x1f\x46ragmentTranslationChangedEvent\x12\x13\n\x0b\x66ragment_id\x18\n \x01(\t\x12\x34\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32$.eolymp.content.Fragment.Translation\x12\x33\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32$.eolymp.content.Fragment.Translation\"b\n\x15\x44\x65scribeFragmentInput\x12\x13\n\x0b\x66ragment_id\x18\x01 \x01(\t\x12\x34\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32$.eolymp.content.Fragment.Extra.Field\"D\n\x16\x44\x65scribeFragmentOutput\x12*\n\x08\x66ragment\x18\x01 \x01(\x0b\x32\x18.eolymp.content.Fragment\"\xa2\x04\n\x12ListFragmentsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.content.ListFragmentsInput.Filter\x12\x35\n\x04sort\x18\x32 \x01(\x0e\x32\'.eolymp.content.ListFragmentsInput.Sort\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12\x0f\n\x06locale\x18\xe2\x08 \x01(\t\x12\x34\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32$.eolymp.content.Fragment.Extra.Field\x1a\xd8\x01\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04path\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x30\n\x06locale\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12/\n\x05label\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"-\n\x04Sort\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x08\n\x04PATH\x10\x01\x12\x0e\n\nCREATED_AT\x10\x02\"M\n\x13ListFragmentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.content.Fragment\"A\n\x13\x43reateFragmentInput\x12*\n\x08\x66ragment\x18\x01 \x01(\x0b\x32\x18.eolymp.content.Fragment\"+\n\x14\x43reateFragmentOutput\x12\x13\n\x0b\x66ragment_id\x18\x01 \x01(\t\"\x8b\x01\n\x13UpdateFragmentInput\x12\x33\n\x05patch\x18\x03 \x03(\x0e\x32$.eolymp.content.Fragment.Patch.Field\x12\x13\n\x0b\x66ragment_id\x18\x01 \x01(\t\x12*\n\x08\x66ragment\x18\x02 \x01(\x0b\x32\x18.eolymp.content.Fragment\"\x16\n\x14UpdateFragmentOutput\"*\n\x13\x44\x65leteFragmentInput\x12\x13\n\x0b\x66ragment_id\x18\x01 \x01(\t\"\x16\n\x14\x44\x65leteFragmentOutput\"\x80\x01\n\x16TranslateFragmentInput\x12\x13\n\x0b\x66ragment_id\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0e\n\x06target\x18\x03 \x03(\t\x12\x18\n\x10target_automatic\x18\x04 \x01(\x08\x12\x17\n\x0foverride_manual\x18\x05 \x01(\x08\")\n\x17TranslateFragmentOutput\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\x85\x01\n DescribeFragmentTranslationInput\x12\x13\n\x0b\x66ragment_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\x12\x34\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32$.eolymp.content.Fragment.Extra.Field\"^\n!DescribeFragmentTranslationOutput\x12\x39\n\x0btranslation\x18\x01 \x01(\x0b\x32$.eolymp.content.Fragment.Translation\"\xc6\x02\n\x1dListFragmentTranslationsInput\x12\x13\n\x0b\x66ragment_id\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x45\n\x07\x66ilters\x18( \x01(\x0b\x32\x34.eolymp.content.ListFragmentTranslationsInput.Filter\x12\x34\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32$.eolymp.content.Fragment.Extra.Field\x1au\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06locale\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"d\n\x1eListFragmentTranslationsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x33\n\x05items\x18\x02 \x03(\x0b\x32$.eolymp.content.Fragment.Translation\"p\n\x1e\x43reateFragmentTranslationInput\x12\x13\n\x0b\x66ragment_id\x18\x01 \x01(\t\x12\x39\n\x0btranslation\x18\x02 \x01(\x0b\x32$.eolymp.content.Fragment.Translation\"9\n\x1f\x43reateFragmentTranslationOutput\x12\x16\n\x0etranslation_id\x18\x01 \x01(\t\"\x88\x01\n\x1eUpdateFragmentTranslationInput\x12\x13\n\x0b\x66ragment_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\x12\x39\n\x0btranslation\x18\x03 \x01(\x0b\x32$.eolymp.content.Fragment.Translation\"!\n\x1fUpdateFragmentTranslationOutput\"M\n\x1e\x44\x65leteFragmentTranslationInput\x12\x13\n\x0b\x66ragment_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\"!\n\x1f\x44\x65leteFragmentTranslationOutput\"g\n\x11\x44\x65scribePathInput\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x02 \x01(\t\x12\x34\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32$.eolymp.content.Fragment.Extra.Field\"@\n\x12\x44\x65scribePathOutput\x12*\n\x08\x66ragment\x18\x01 \x01(\x0b\x32\x18.eolymp.content.Fragment\"f\n\x10ListParentsInput\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x02 \x01(\t\x12\x34\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32$.eolymp.content.Fragment.Extra.Field\"K\n\x11ListParentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.content.Fragment2\x9a\x17\n\x0e\x43ontentService\x12\xbb\x01\n\x10\x44\x65scribeFragment\x12%.eolymp.content.DescribeFragmentInput\x1a&.eolymp.content.DescribeFragmentOutput\"X\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xe3\n\x1c\x8a\xe3\n\x18typewriter:fragment:read\x82\xd3\xe4\x93\x02\"\x12 /content/fragments/{fragment_id}\x12\xa3\x01\n\rListFragments\x12\".eolymp.content.ListFragmentsInput\x1a#.eolymp.content.ListFragmentsOutput\"I\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x1c\x8a\xe3\n\x18typewriter:fragment:read\x82\xd3\xe4\x93\x02\x14\x12\x12/content/fragments\x12\xa7\x01\n\x0e\x43reateFragment\x12#.eolymp.content.CreateFragmentInput\x1a$.eolymp.content.CreateFragmentOutput\"J\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\x82\xd3\xe4\x93\x02\x14\"\x12/content/fragments\x12\xb5\x01\n\x0eUpdateFragment\x12#.eolymp.content.UpdateFragmentInput\x1a$.eolymp.content.UpdateFragmentOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\x82\xd3\xe4\x93\x02\"\x1a /content/fragments/{fragment_id}\x12\xb5\x01\n\x0e\x44\x65leteFragment\x12#.eolymp.content.DeleteFragmentInput\x1a$.eolymp.content.DeleteFragmentOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\x82\xd3\xe4\x93\x02\"* /content/fragments/{fragment_id}\x12\xc8\x01\n\x11TranslateFragment\x12&.eolymp.content.TranslateFragmentInput\x1a\'.eolymp.content.TranslateFragmentOutput\"b\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\x82\xd3\xe4\x93\x02,\"*/content/fragments/{fragment_id}/translate\x12\xb9\x02\n\x1b\x44\x65scribeFragmentTranslation\x12\x30.eolymp.content.DescribeFragmentTranslationInput\x1a\x31.eolymp.content.DescribeFragmentTranslationOutput\"\xb4\x01\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xe3\n\x1c\x8a\xe3\n\x18typewriter:fragment:read\x82\xd3\xe4\x93\x02~\x12>/content/fragments/{fragment_id}/translations/{translation_id}Z<\x12:/content/fragments/{fragment_id}/variants/{translation_id}\x12\x8d\x02\n\x18ListFragmentTranslations\x12-.eolymp.content.ListFragmentTranslationsInput\x1a..eolymp.content.ListFragmentTranslationsOutput\"\x91\x01\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x1c\x8a\xe3\n\x18typewriter:fragment:read\x82\xd3\xe4\x93\x02\\\x12-/content/fragments/{fragment_id}/translationsZ+\x12)/content/fragments/{fragment_id}/variants\x12\x91\x02\n\x19\x43reateFragmentTranslation\x12..eolymp.content.CreateFragmentTranslationInput\x1a/.eolymp.content.CreateFragmentTranslationOutput\"\x92\x01\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\x82\xd3\xe4\x93\x02\\\"-/content/fragments/{fragment_id}/translationsZ+\")/content/fragments/{fragment_id}/variants\x12\xb3\x02\n\x19UpdateFragmentTranslation\x12..eolymp.content.UpdateFragmentTranslationInput\x1a/.eolymp.content.UpdateFragmentTranslationOutput\"\xb4\x01\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\x82\xd3\xe4\x93\x02~\x1a>/content/fragments/{fragment_id}/translations/{translation_id}Z<\x1a:/content/fragments/{fragment_id}/variants/{translation_id}\x12\xb3\x02\n\x19\x44\x65leteFragmentTranslation\x12..eolymp.content.DeleteFragmentTranslationInput\x1a/.eolymp.content.DeleteFragmentTranslationOutput\"\xb4\x01\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\x82\xd3\xe4\x93\x02~*>/content/fragments/{fragment_id}/translations/{translation_id}Z<*:/content/fragments/{fragment_id}/variants/{translation_id}\x12\x9c\x01\n\x0c\x44\x65scribePath\x12!.eolymp.content.DescribePathInput\x1a\".eolymp.content.DescribePathOutput\"E\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xe3\n\x1c\x8a\xe3\n\x18typewriter:fragment:read\x82\xd3\xe4\x93\x02\x0f\x12\r/content/path\x12\x9c\x01\n\x0bListParents\x12 .eolymp.content.ListParentsInput\x1a!.eolymp.content.ListParentsOutput\"H\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xe3\n\x1c\x8a\xe3\n\x18typewriter:fragment:read\x82\xd3\xe4\x93\x02\x12\x12\x10/content/parents\x1a\x35\x82\xf0\xf0\xe4\x01\x15\x65olymp.universe.Space\x82\xf0\xf0\xe4\x01\x14\x65olymp.judge.ContestB1Z/github.com/eolymp/go-sdk/eolymp/content;contentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.content.content_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/content;content'
  _globals['_CONTENTSERVICE']._loaded_options = None
  _globals['_CONTENTSERVICE']._serialized_options = b'\202\360\360\344\001\025eolymp.universe.Space\202\360\360\344\001\024eolymp.judge.Contest'
  _globals['_CONTENTSERVICE'].methods_by_name['DescribeFragment']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['DescribeFragment']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\343\n\034\212\343\n\030typewriter:fragment:read\202\323\344\223\002\"\022 /content/fragments/{fragment_id}'
  _globals['_CONTENTSERVICE'].methods_by_name['ListFragments']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['ListFragments']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\034\212\343\n\030typewriter:fragment:read\202\323\344\223\002\024\022\022/content/fragments'
  _globals['_CONTENTSERVICE'].methods_by_name['CreateFragment']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['CreateFragment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\035\212\343\n\031typewriter:fragment:write\202\323\344\223\002\024\"\022/content/fragments'
  _globals['_CONTENTSERVICE'].methods_by_name['UpdateFragment']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['UpdateFragment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\035\212\343\n\031typewriter:fragment:write\202\323\344\223\002\"\032 /content/fragments/{fragment_id}'
  _globals['_CONTENTSERVICE'].methods_by_name['DeleteFragment']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['DeleteFragment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\035\212\343\n\031typewriter:fragment:write\202\323\344\223\002\"* /content/fragments/{fragment_id}'
  _globals['_CONTENTSERVICE'].methods_by_name['TranslateFragment']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['TranslateFragment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\035\212\343\n\031typewriter:fragment:write\202\323\344\223\002,\"*/content/fragments/{fragment_id}/translate'
  _globals['_CONTENTSERVICE'].methods_by_name['DescribeFragmentTranslation']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['DescribeFragmentTranslation']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\343\n\034\212\343\n\030typewriter:fragment:read\202\323\344\223\002~\022>/content/fragments/{fragment_id}/translations/{translation_id}Z<\022:/content/fragments/{fragment_id}/variants/{translation_id}'
  _globals['_CONTENTSERVICE'].methods_by_name['ListFragmentTranslations']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['ListFragmentTranslations']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\034\212\343\n\030typewriter:fragment:read\202\323\344\223\002\\\022-/content/fragments/{fragment_id}/translationsZ+\022)/content/fragments/{fragment_id}/variants'
  _globals['_CONTENTSERVICE'].methods_by_name['CreateFragmentTranslation']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['CreateFragmentTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\035\212\343\n\031typewriter:fragment:write\202\323\344\223\002\\\"-/content/fragments/{fragment_id}/translationsZ+\")/content/fragments/{fragment_id}/variants'
  _globals['_CONTENTSERVICE'].methods_by_name['UpdateFragmentTranslation']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['UpdateFragmentTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\035\212\343\n\031typewriter:fragment:write\202\323\344\223\002~\032>/content/fragments/{fragment_id}/translations/{translation_id}Z<\032:/content/fragments/{fragment_id}/variants/{translation_id}'
  _globals['_CONTENTSERVICE'].methods_by_name['DeleteFragmentTranslation']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['DeleteFragmentTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\035\212\343\n\031typewriter:fragment:write\202\323\344\223\002~*>/content/fragments/{fragment_id}/translations/{translation_id}Z<*:/content/fragments/{fragment_id}/variants/{translation_id}'
  _globals['_CONTENTSERVICE'].methods_by_name['DescribePath']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['DescribePath']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\343\n\034\212\343\n\030typewriter:fragment:read\202\323\344\223\002\017\022\r/content/path'
  _globals['_CONTENTSERVICE'].methods_by_name['ListParents']._loaded_options = None
  _globals['_CONTENTSERVICE'].methods_by_name['ListParents']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\343\n\034\212\343\n\030typewriter:fragment:read\202\323\344\223\002\022\022\020/content/parents'
  _globals['_FRAGMENTCHANGEDEVENT']._serialized_start=299
  _globals['_FRAGMENTCHANGEDEVENT']._serialized_end=419
  _globals['_FRAGMENTTRANSLATIONCHANGEDEVENT']._serialized_start=422
  _globals['_FRAGMENTTRANSLATIONCHANGEDEVENT']._serialized_end=583
  _globals['_DESCRIBEFRAGMENTINPUT']._serialized_start=585
  _globals['_DESCRIBEFRAGMENTINPUT']._serialized_end=683
  _globals['_DESCRIBEFRAGMENTOUTPUT']._serialized_start=685
  _globals['_DESCRIBEFRAGMENTOUTPUT']._serialized_end=753
  _globals['_LISTFRAGMENTSINPUT']._serialized_start=756
  _globals['_LISTFRAGMENTSINPUT']._serialized_end=1302
  _globals['_LISTFRAGMENTSINPUT_FILTER']._serialized_start=1039
  _globals['_LISTFRAGMENTSINPUT_FILTER']._serialized_end=1255
  _globals['_LISTFRAGMENTSINPUT_SORT']._serialized_start=1257
  _globals['_LISTFRAGMENTSINPUT_SORT']._serialized_end=1302
  _globals['_LISTFRAGMENTSOUTPUT']._serialized_start=1304
  _globals['_LISTFRAGMENTSOUTPUT']._serialized_end=1381
  _globals['_CREATEFRAGMENTINPUT']._serialized_start=1383
  _globals['_CREATEFRAGMENTINPUT']._serialized_end=1448
  _globals['_CREATEFRAGMENTOUTPUT']._serialized_start=1450
  _globals['_CREATEFRAGMENTOUTPUT']._serialized_end=1493
  _globals['_UPDATEFRAGMENTINPUT']._serialized_start=1496
  _globals['_UPDATEFRAGMENTINPUT']._serialized_end=1635
  _globals['_UPDATEFRAGMENTOUTPUT']._serialized_start=1637
  _globals['_UPDATEFRAGMENTOUTPUT']._serialized_end=1659
  _globals['_DELETEFRAGMENTINPUT']._serialized_start=1661
  _globals['_DELETEFRAGMENTINPUT']._serialized_end=1703
  _globals['_DELETEFRAGMENTOUTPUT']._serialized_start=1705
  _globals['_DELETEFRAGMENTOUTPUT']._serialized_end=1727
  _globals['_TRANSLATEFRAGMENTINPUT']._serialized_start=1730
  _globals['_TRANSLATEFRAGMENTINPUT']._serialized_end=1858
  _globals['_TRANSLATEFRAGMENTOUTPUT']._serialized_start=1860
  _globals['_TRANSLATEFRAGMENTOUTPUT']._serialized_end=1901
  _globals['_DESCRIBEFRAGMENTTRANSLATIONINPUT']._serialized_start=1904
  _globals['_DESCRIBEFRAGMENTTRANSLATIONINPUT']._serialized_end=2037
  _globals['_DESCRIBEFRAGMENTTRANSLATIONOUTPUT']._serialized_start=2039
  _globals['_DESCRIBEFRAGMENTTRANSLATIONOUTPUT']._serialized_end=2133
  _globals['_LISTFRAGMENTTRANSLATIONSINPUT']._serialized_start=2136
  _globals['_LISTFRAGMENTTRANSLATIONSINPUT']._serialized_end=2462
  _globals['_LISTFRAGMENTTRANSLATIONSINPUT_FILTER']._serialized_start=2345
  _globals['_LISTFRAGMENTTRANSLATIONSINPUT_FILTER']._serialized_end=2462
  _globals['_LISTFRAGMENTTRANSLATIONSOUTPUT']._serialized_start=2464
  _globals['_LISTFRAGMENTTRANSLATIONSOUTPUT']._serialized_end=2564
  _globals['_CREATEFRAGMENTTRANSLATIONINPUT']._serialized_start=2566
  _globals['_CREATEFRAGMENTTRANSLATIONINPUT']._serialized_end=2678
  _globals['_CREATEFRAGMENTTRANSLATIONOUTPUT']._serialized_start=2680
  _globals['_CREATEFRAGMENTTRANSLATIONOUTPUT']._serialized_end=2737
  _globals['_UPDATEFRAGMENTTRANSLATIONINPUT']._serialized_start=2740
  _globals['_UPDATEFRAGMENTTRANSLATIONINPUT']._serialized_end=2876
  _globals['_UPDATEFRAGMENTTRANSLATIONOUTPUT']._serialized_start=2878
  _globals['_UPDATEFRAGMENTTRANSLATIONOUTPUT']._serialized_end=2911
  _globals['_DELETEFRAGMENTTRANSLATIONINPUT']._serialized_start=2913
  _globals['_DELETEFRAGMENTTRANSLATIONINPUT']._serialized_end=2990
  _globals['_DELETEFRAGMENTTRANSLATIONOUTPUT']._serialized_start=2992
  _globals['_DELETEFRAGMENTTRANSLATIONOUTPUT']._serialized_end=3025
  _globals['_DESCRIBEPATHINPUT']._serialized_start=3027
  _globals['_DESCRIBEPATHINPUT']._serialized_end=3130
  _globals['_DESCRIBEPATHOUTPUT']._serialized_start=3132
  _globals['_DESCRIBEPATHOUTPUT']._serialized_end=3196
  _globals['_LISTPARENTSINPUT']._serialized_start=3198
  _globals['_LISTPARENTSINPUT']._serialized_end=3300
  _globals['_LISTPARENTSOUTPUT']._serialized_start=3302
  _globals['_LISTPARENTSOUTPUT']._serialized_end=3377
  _globals['_CONTENTSERVICE']._serialized_start=3380
  _globals['_CONTENTSERVICE']._serialized_end=6350
# @@protoc_insertion_point(module_scope)



import datetime

from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Fragment(_message.Message):
    __slots__ = ("id", "path", "locale", "draft", "title", "content", "created_at", "updated_at", "labels")
    class Extra(_message.Message):
        __slots__ = ()
        class Field(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNKNOWN_EXTRA: _ClassVar[Fragment.Extra.Field]
            CONTENT_RENDER: _ClassVar[Fragment.Extra.Field]
            CONTENT_VALUE: _ClassVar[Fragment.Extra.Field]
        UNKNOWN_EXTRA: Fragment.Extra.Field
        CONTENT_RENDER: Fragment.Extra.Field
        CONTENT_VALUE: Fragment.Extra.Field
        def __init__(self) -> None: ...
    class Patch(_message.Message):
        __slots__ = ()
        class Field(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNKNOWN_PATCH: _ClassVar[Fragment.Patch.Field]
            PATH: _ClassVar[Fragment.Patch.Field]
            LOCALE: _ClassVar[Fragment.Patch.Field]
            DRAFT: _ClassVar[Fragment.Patch.Field]
            TITLE: _ClassVar[Fragment.Patch.Field]
            CONTENT: _ClassVar[Fragment.Patch.Field]
            LABELS: _ClassVar[Fragment.Patch.Field]
        UNKNOWN_PATCH: Fragment.Patch.Field
        PATH: Fragment.Patch.Field
        LOCALE: Fragment.Patch.Field
        DRAFT: Fragment.Patch.Field
        TITLE: Fragment.Patch.Field
        CONTENT: Fragment.Patch.Field
        LABELS: Fragment.Patch.Field
        def __init__(self) -> None: ...
    class Translation(_message.Message):
        __slots__ = ("id", "locale", "title", "content", "automatic")
        ID_FIELD_NUMBER: _ClassVar[int]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        TITLE_FIELD_NUMBER: _ClassVar[int]
        CONTENT_FIELD_NUMBER: _ClassVar[int]
        AUTOMATIC_FIELD_NUMBER: _ClassVar[int]
        id: str
        locale: str
        title: str
        content: _content_pb2.Content
        automatic: bool
        def __init__(self, id: _Optional[str] = ..., locale: _Optional[str] = ..., title: _Optional[str] = ..., content: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., automatic: bool = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    DRAFT_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    id: str
    path: str
    locale: str
    draft: bool
    title: str
    content: _content_pb2.Content
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    labels: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[str] = ..., path: _Optional[str] = ..., locale: _Optional[str] = ..., draft: bool = ..., title: _Optional[str] = ..., content: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., labels: _Optional[_Iterable[str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/acl/policy_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/acl/policy_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.acl import policy_pb2 as eolymp_dot_acl_dot_policy__pb2
from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import namespace_pb2 as eolymp_dot_annotations_dot_namespace__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x65olymp/acl/policy_service.proto\x12\neolymp.acl\x1a\x17\x65olymp/acl/policy.proto\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/namespace.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a!eolymp/wellknown/expression.proto\"7\n\x11\x43reatePolicyInput\x12\"\n\x06policy\x18\x01 \x01(\x0b\x32\x12.eolymp.acl.Policy\"\'\n\x12\x43reatePolicyOutput\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\"\xa6\x01\n\x11UpdatePolicyInput\x12\x32\n\x05patch\x18\n \x03(\x0e\x32#.eolymp.acl.UpdatePolicyInput.Patch\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\x12\"\n\x06policy\x18\x02 \x01(\x0b\x32\x12.eolymp.acl.Policy\"&\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\n\n\x06\x41LLOWS\x10\x02\"\x14\n\x12UpdatePolicyOutput\"&\n\x11\x44\x65letePolicyInput\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\"\x14\n\x12\x44\x65letePolicyOutput\"(\n\x13\x44\x65scribePolicyInput\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\":\n\x14\x44\x65scribePolicyOutput\x12\"\n\x06policy\x18\x01 \x01(\x0b\x32\x12.eolymp.acl.Policy\"\xc7\x02\n\x11ListPoliciesInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x35\n\x07\x66ilters\x18( \x01(\x0b\x32$.eolymp.acl.ListPoliciesInput.Filter\x1a\xdc\x01\n\x06\x46ilter\x12\r\n\x05query\x18\n \x01(\t\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tprincipal\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x32\n\x08resource\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"F\n\x12ListPoliciesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12!\n\x05items\x18\x02 \x03(\x0b\x32\x12.eolymp.acl.Policy\"m\n\x11\x43opyPoliciesInput\x12\x15\n\rsrc_principal\x18\x01 \x01(\t\x12\x15\n\rdst_principal\x18\x02 \x01(\t\x12\x14\n\x0csrc_resource\x18\x03 \x01(\t\x12\x14\n\x0c\x64st_resource\x18\x04 \x01(\t\"*\n\x12\x43opyPoliciesOutput\x12\x14\n\x0c\x63opies_count\x18\x01 \x01(\x05\x32\x82\x06\n\rPolicyService\x12o\n\x0c\x43reatePolicy\x12\x1d.eolymp.acl.CreatePolicyInput\x1a\x1e.eolymp.acl.CreatePolicyOutput\" \xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x0b\"\t/policies\x12{\n\x0cUpdatePolicy\x12\x1d.eolymp.acl.UpdatePolicyInput\x1a\x1e.eolymp.acl.UpdatePolicyOutput\",\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x17\x1a\x15/policies/{policy_id}\x12{\n\x0c\x44\x65letePolicy\x12\x1d.eolymp.acl.DeletePolicyInput\x1a\x1e.eolymp.acl.DeletePolicyOutput\",\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x17*\x15/policies/{policy_id}\x12\x81\x01\n\x0e\x44\x65scribePolicy\x12\x1f.eolymp.acl.DescribePolicyInput\x1a .eolymp.acl.DescribePolicyOutput\",\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x17\x12\x15/policies/{policy_id}\x12o\n\x0cListPolicies\x12\x1d.eolymp.acl.ListPoliciesInput\x1a\x1e.eolymp.acl.ListPoliciesOutput\" \xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x0b\x12\t/policies\x12t\n\x0c\x43opyPolicies\x12\x1d.eolymp.acl.CopyPoliciesInput\x1a\x1e.eolymp.acl.CopyPoliciesOutput\"%\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x10\"\x0e/policies:copy\x1a\x1b\x82\xf0\xf0\xe4\x01\x15\x65olymp.universe.SpaceB)Z\'github.com/eolymp/go-sdk/eolymp/acl;aclb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.acl.policy_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\'github.com/eolymp/go-sdk/eolymp/acl;acl'
  _globals['_POLICYSERVICE']._loaded_options = None
  _globals['_POLICYSERVICE']._serialized_options = b'\202\360\360\344\001\025eolymp.universe.Space'
  _globals['_POLICYSERVICE'].methods_by_name['CreatePolicy']._loaded_options = None
  _globals['_POLICYSERVICE'].methods_by_name['CreatePolicy']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\013\"\t/policies'
  _globals['_POLICYSERVICE'].methods_by_name['UpdatePolicy']._loaded_options = None
  _globals['_POLICYSERVICE'].methods_by_name['UpdatePolicy']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\027\032\025/policies/{policy_id}'
  _globals['_POLICYSERVICE'].methods_by_name['DeletePolicy']._loaded_options = None
  _globals['_POLICYSERVICE'].methods_by_name['DeletePolicy']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\027*\025/policies/{policy_id}'
  _globals['_POLICYSERVICE'].methods_by_name['DescribePolicy']._loaded_options = None
  _globals['_POLICYSERVICE'].methods_by_name['DescribePolicy']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n\024\202\323\344\223\002\027\022\025/policies/{policy_id}'
  _globals['_POLICYSERVICE'].methods_by_name['ListPolicies']._loaded_options = None
  _globals['_POLICYSERVICE'].methods_by_name['ListPolicies']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n\024\202\323\344\223\002\013\022\t/policies'
  _globals['_POLICYSERVICE'].methods_by_name['CopyPolicies']._loaded_options = None
  _globals['_POLICYSERVICE'].methods_by_name['CopyPolicies']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n\024\202\323\344\223\002\020\"\016/policies:copy'
  _globals['_CREATEPOLICYINPUT']._serialized_start=210
  _globals['_CREATEPOLICYINPUT']._serialized_end=265
  _globals['_CREATEPOLICYOUTPUT']._serialized_start=267
  _globals['_CREATEPOLICYOUTPUT']._serialized_end=306
  _globals['_UPDATEPOLICYINPUT']._serialized_start=309
  _globals['_UPDATEPOLICYINPUT']._serialized_end=475
  _globals['_UPDATEPOLICYINPUT_PATCH']._serialized_start=437
  _globals['_UPDATEPOLICYINPUT_PATCH']._serialized_end=475
  _globals['_UPDATEPOLICYOUTPUT']._serialized_start=477
  _globals['_UPDATEPOLICYOUTPUT']._serialized_end=497
  _globals['_DELETEPOLICYINPUT']._serialized_start=499
  _globals['_DELETEPOLICYINPUT']._serialized_end=537
  _globals['_DELETEPOLICYOUTPUT']._serialized_start=539
  _globals['_DELETEPOLICYOUTPUT']._serialized_end=559
  _globals['_DESCRIBEPOLICYINPUT']._serialized_start=561
  _globals['_DESCRIBEPOLICYINPUT']._serialized_end=601
  _globals['_DESCRIBEPOLICYOUTPUT']._serialized_start=603
  _globals['_DESCRIBEPOLICYOUTPUT']._serialized_end=661
  _globals['_LISTPOLICIESINPUT']._serialized_start=664
  _globals['_LISTPOLICIESINPUT']._serialized_end=991
  _globals['_LISTPOLICIESINPUT_FILTER']._serialized_start=771
  _globals['_LISTPOLICIESINPUT_FILTER']._serialized_end=991
  _globals['_LISTPOLICIESOUTPUT']._serialized_start=993
  _globals['_LISTPOLICIESOUTPUT']._serialized_end=1063
  _globals['_COPYPOLICIESINPUT']._serialized_start=1065
  _globals['_COPYPOLICIESINPUT']._serialized_end=1174
  _globals['_COPYPOLICIESOUTPUT']._serialized_start=1176
  _globals['_COPYPOLICIESOUTPUT']._serialized_end=1218
  _globals['_POLICYSERVICE']._serialized_start=1221
  _globals['_POLICYSERVICE']._serialized_end=1991
# @@protoc_insertion_point(module_scope)



from .post_type_service_pb2 import *
from .post_service_pb2 import *
from .translation_service_pb2 import *
from .post_pb2 import *
from .render_service_http import *
from .translation_service_http import *
from .content_fragment_pb2 import *
from .post_type_pb2 import *
from .post_type_service_http import *
from .content_service_http import *
from .post_service_http import *
from .render_service_pb2 import *
from .content_service_pb2 import *



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Group(_message.Message):
    __slots__ = ("id", "name", "description", "external_ref", "icon", "badge", "color", "metadata")
    class Patch(_message.Message):
        __slots__ = ()
        class Field(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNKNOWN: _ClassVar[Group.Patch.Field]
            NAME: _ClassVar[Group.Patch.Field]
            DESCRIPTION: _ClassVar[Group.Patch.Field]
            EXTERNAL_REF: _ClassVar[Group.Patch.Field]
            ICON: _ClassVar[Group.Patch.Field]
            BADGE: _ClassVar[Group.Patch.Field]
            COLOR: _ClassVar[Group.Patch.Field]
            METADATA: _ClassVar[Group.Patch.Field]
        UNKNOWN: Group.Patch.Field
        NAME: Group.Patch.Field
        DESCRIPTION: Group.Patch.Field
        EXTERNAL_REF: Group.Patch.Field
        ICON: Group.Patch.Field
        BADGE: Group.Patch.Field
        COLOR: Group.Patch.Field
        METADATA: Group.Patch.Field
        def __init__(self) -> None: ...
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_REF_FIELD_NUMBER: _ClassVar[int]
    ICON_FIELD_NUMBER: _ClassVar[int]
    BADGE_FIELD_NUMBER: _ClassVar[int]
    COLOR_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    external_ref: str
    icon: str
    badge: str
    color: str
    metadata: _containers.ScalarMap[str, str]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., external_ref: _Optional[str] = ..., icon: _Optional[str] = ..., badge: _Optional[str] = ..., color: _Optional[str] = ..., metadata: _Optional[_Mapping[str, str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/community/group.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/community/group.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/community/group.proto\x12\x10\x65olymp.community\"\xdd\x02\n\x05Group\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0c\x65xternal_ref\x18\x04 \x01(\t\x12\x0c\n\x04icon\x18\n \x01(\t\x12\r\n\x05\x62\x61\x64ge\x18\x0b \x01(\t\x12\r\n\x05\x63olor\x18\x0c \x01(\t\x12\x38\n\x08metadata\x18\x80\x08 \x03(\x0b\x32%.eolymp.community.Group.MetadataEntry\x1ax\n\x05Patch\"o\n\x05\x46ield\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\x0f\n\x0b\x44\x45SCRIPTION\x10\x02\x12\x10\n\x0c\x45XTERNAL_REF\x10\x03\x12\x08\n\x04ICON\x10\x04\x12\t\n\x05\x42\x41\x44GE\x10\x05\x12\t\n\x05\x43OLOR\x10\x06\x12\x0c\n\x08METADATA\x10\x07\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x35Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.group_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _globals['_GROUP_METADATAENTRY']._loaded_options = None
  _globals['_GROUP_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_GROUP']._serialized_start=51
  _globals['_GROUP']._serialized_end=400
  _globals['_GROUP_PATCH']._serialized_start=231
  _globals['_GROUP_PATCH']._serialized_end=351
  _globals['_GROUP_PATCH_FIELD']._serialized_start=240
  _globals['_GROUP_PATCH_FIELD']._serialized_end=351
  _globals['_GROUP_METADATAENTRY']._serialized_start=353
  _globals['_GROUP_METADATAENTRY']._serialized_end=400
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/commerce/fulfillment_server.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/commerce/fulfillment_server.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import namespace_pb2 as eolymp_dot_annotations_dot_namespace__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(eolymp/commerce/fulfillment_server.proto\x12\x0f\x65olymp.commerce\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/namespace.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x18\x65olymp/ecm/content.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"&\n\x12\x41llocateStockInput\x12\x10\n\x08order_id\x18\x01 \x01(\t\"\x15\n\x13\x41llocateStockOutput\"I\n\x10RejectOrderInput\x12\x10\n\x08order_id\x18\x01 \x01(\t\x12#\n\x06reason\x18\x02 \x01(\x0b\x32\x13.eolymp.ecm.Content\"\x13\n\x11RejectOrderOutput\"b\n\x11ProcessOrderInput\x12\x10\n\x08order_id\x18\x01 \x01(\t\x12;\n\x17\x65stimated_shipping_date\x18- \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x14\n\x12ProcessOrderOutput\"R\n\x0eShipOrderInput\x12\x10\n\x08order_id\x18\x01 \x01(\t\x12\x15\n\rtracking_link\x18\x02 \x01(\t\x12\x17\n\x0ftracking_number\x18\x03 \x01(\t\"\x11\n\x0fShipOrderOutput\"&\n\x12\x43ompleteOrderInput\x12\x10\n\x08order_id\x18\x01 \x01(\t\"\x15\n\x13\x43ompleteOrderOutput2\x99\x07\n\x12\x46ulfillmentService\x12\xb1\x01\n\rAllocateStock\x12#.eolymp.commerce.AllocateStockInput\x1a$.eolymp.commerce.AllocateStockOutput\"U\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommerce:orders:write\x82\xd3\xe4\x93\x02#\"!/store/orders/{order_id}/allocate\x12\xa9\x01\n\x0bRejectOrder\x12!.eolymp.commerce.RejectOrderInput\x1a\".eolymp.commerce.RejectOrderOutput\"S\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommerce:orders:write\x82\xd3\xe4\x93\x02!\"\x1f/store/orders/{order_id}/reject\x12\xad\x01\n\x0cProcessOrder\x12\".eolymp.commerce.ProcessOrderInput\x1a#.eolymp.commerce.ProcessOrderOutput\"T\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommerce:orders:write\x82\xd3\xe4\x93\x02\"\" /store/orders/{order_id}/process\x12\xa1\x01\n\tShipOrder\x12\x1f.eolymp.commerce.ShipOrderInput\x1a .eolymp.commerce.ShipOrderOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommerce:orders:write\x82\xd3\xe4\x93\x02\x1f\"\x1d/store/orders/{order_id}/ship\x12\xb1\x01\n\rCompleteOrder\x12#.eolymp.commerce.CompleteOrderInput\x1a$.eolymp.commerce.CompleteOrderOutput\"U\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommerce:orders:write\x82\xd3\xe4\x93\x02#\"!/store/orders/{order_id}/complete\x1a\x1b\x82\xf0\xf0\xe4\x01\x15\x65olymp.universe.SpaceB3Z1github.com/eolymp/go-sdk/eolymp/commerce;commerceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.commerce.fulfillment_server_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/commerce;commerce'
  _globals['_FULFILLMENTSERVICE']._loaded_options = None
  _globals['_FULFILLMENTSERVICE']._serialized_options = b'\202\360\360\344\001\025eolymp.universe.Space'
  _globals['_FULFILLMENTSERVICE'].methods_by_name['AllocateStock']._loaded_options = None
  _globals['_FULFILLMENTSERVICE'].methods_by_name['AllocateStock']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025commerce:orders:write\202\323\344\223\002#\"!/store/orders/{order_id}/allocate'
  _globals['_FULFILLMENTSERVICE'].methods_by_name['RejectOrder']._loaded_options = None
  _globals['_FULFILLMENTSERVICE'].methods_by_name['RejectOrder']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025commerce:orders:write\202\323\344\223\002!\"\037/store/orders/{order_id}/reject'
  _globals['_FULFILLMENTSERVICE'].methods_by_name['ProcessOrder']._loaded_options = None
  _globals['_FULFILLMENTSERVICE'].methods_by_name['ProcessOrder']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025commerce:orders:write\202\323\344\223\002\"\" /store/orders/{order_id}/process'
  _globals['_FULFILLMENTSERVICE'].methods_by_name['ShipOrder']._loaded_options = None
  _globals['_FULFILLMENTSERVICE'].methods_by_name['ShipOrder']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025commerce:orders:write\202\323\344\223\002\037\"\035/store/orders/{order_id}/ship'
  _globals['_FULFILLMENTSERVICE'].methods_by_name['CompleteOrder']._loaded_options = None
  _globals['_FULFILLMENTSERVICE'].methods_by_name['CompleteOrder']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025commerce:orders:write\202\323\344\223\002#\"!/store/orders/{order_id}/complete'
  _globals['_ALLOCATESTOCKINPUT']._serialized_start=255
  _globals['_ALLOCATESTOCKINPUT']._serialized_end=293
  _globals['_ALLOCATESTOCKOUTPUT']._serialized_start=295
  _globals['_ALLOCATESTOCKOUTPUT']._serialized_end=316
  _globals['_REJECTORDERINPUT']._serialized_start=318
  _globals['_REJECTORDERINPUT']._serialized_end=391
  _globals['_REJECTORDEROUTPUT']._serialized_start=393
  _globals['_REJECTORDEROUTPUT']._serialized_end=412
  _globals['_PROCESSORDERINPUT']._serialized_start=414
  _globals['_PROCESSORDERINPUT']._serialized_end=512
  _globals['_PROCESSORDEROUTPUT']._serialized_start=514
  _globals['_PROCESSORDEROUTPUT']._serialized_end=534
  _globals['_SHIPORDERINPUT']._serialized_start=536
  _globals['_SHIPORDERINPUT']._serialized_end=618
  _globals['_SHIPORDEROUTPUT']._serialized_start=620
  _globals['_SHIPORDEROUTPUT']._serialized_end=637
  _globals['_COMPLETEORDERINPUT']._serialized_start=639
  _globals['_COMPLETEORDERINPUT']._serialized_end=677
  _globals['_COMPLETEORDEROUTPUT']._serialized_start=679
  _globals['_COMPLETEORDEROUTPUT']._serialized_end=700
  _globals['_FULFILLMENTSERVICE']._serialized_start=703
  _globals['_FULFILLMENTSERVICE']._serialized_end=1624
# @@protoc_insertion_point(module_scope)



import datetime

from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Penalty(_message.Message):
    __slots__ = ("id", "summary", "description", "silent", "scope", "created_at", "expires_at", "cancelled_at")
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NO_EXTRA: _ClassVar[Penalty.Extra]
        DESCRIPTION_VALUE: _ClassVar[Penalty.Extra]
        DESCRIPTION_RENDER: _ClassVar[Penalty.Extra]
    NO_EXTRA: Penalty.Extra
    DESCRIPTION_VALUE: Penalty.Extra
    DESCRIPTION_RENDER: Penalty.Extra
    ID_FIELD_NUMBER: _ClassVar[int]
    SUMMARY_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SILENT_FIELD_NUMBER: _ClassVar[int]
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    CANCELLED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    summary: str
    description: _content_pb2.Content
    silent: bool
    scope: _containers.RepeatedScalarFieldContainer[str]
    created_at: _timestamp_pb2.Timestamp
    expires_at: _timestamp_pb2.Timestamp
    cancelled_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., summary: _Optional[str] = ..., description: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., silent: bool = ..., scope: _Optional[_Iterable[str]] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., expires_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., cancelled_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/discussion/thread_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/discussion/thread_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import namespace_pb2 as eolymp_dot_annotations_dot_namespace__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.discussion import message_service_pb2 as eolymp_dot_discussion_dot_message__service__pb2
from eolymp.discussion import subscription_service_pb2 as eolymp_dot_discussion_dot_subscription__service__pb2
from eolymp.discussion import thread_pb2 as eolymp_dot_discussion_dot_thread__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/discussion/thread_service.proto\x12\x11\x65olymp.discussion\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/namespace.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\'eolymp/discussion/message_service.proto\x1a,eolymp/discussion/subscription_service.proto\x1a\x1e\x65olymp/discussion/thread.proto\"%\n\x13\x44\x65scribeThreadInput\x12\x0e\n\x06locale\x18\n \x01(\t\"A\n\x14\x44\x65scribeThreadOutput\x12)\n\x06thread\x18\x01 \x01(\x0b\x32\x19.eolymp.discussion.Thread\"3\n\x0fVoteThreadInput\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12\x0c\n\x04vote\x18\x02 \x01(\x05\"&\n\x10VoteThreadOutput\x12\x12\n\nvote_count\x18\x01 \x01(\x05\x32\xe9\r\n\rThreadService\x12\x81\x01\n\x0e\x44\x65scribeThread\x12&.eolymp.discussion.DescribeThreadInput\x1a\'.eolymp.discussion.DescribeThreadOutput\"\x1e\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\t\x12\x07/thread\x12z\n\nVoteThread\x12\".eolymp.discussion.VoteThreadInput\x1a#.eolymp.discussion.VoteThreadOutput\"#\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x0e\"\x0c/thread/vote\x12\xbf\x01\n\x12UpdateSubscription\x12*.eolymp.discussion.UpdateSubscriptionInput\x1a+.eolymp.discussion.UpdateSubscriptionOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n!\x8a\xe3\n\x1d\x64iscussion:subscription:write\x82\xd3\xe4\x93\x02\x16\x1a\x14/thread/subscription\x12\xba\x01\n\x0f\x44\x65scribeMessage\x12\'.eolymp.discussion.DescribeMessageInput\x1a(.eolymp.discussion.DescribeMessageOutput\"T\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xe3\n\x1b\x8a\xe3\n\x17\x64iscussion:message:read\x82\xd3\xe4\x93\x02\x1f\x12\x1d/thread/messages/{message_id}\x12\xa3\x01\n\x0cListMessages\x12$.eolymp.discussion.ListMessagesInput\x1a%.eolymp.discussion.ListMessagesOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x1b\x8a\xe3\n\x17\x64iscussion:message:read\x82\xd3\xe4\x93\x02\x12\x12\x10/thread/messages\x12\xa1\x01\n\x0bPostMessage\x12#.eolymp.discussion.PostMessageInput\x1a$.eolymp.discussion.PostMessageOutput\"G\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x02\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\x82\xd3\xe4\x93\x02\x12\"\x10/thread/messages\x12\xb4\x01\n\rUpdateMessage\x12%.eolymp.discussion.UpdateMessageInput\x1a&.eolymp.discussion.UpdateMessageOutput\"T\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x02\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\x82\xd3\xe4\x93\x02\x1f\x1a\x1d/thread/messages/{message_id}\x12\xad\x01\n\rDeleteMessage\x12%.eolymp.discussion.DeleteMessageInput\x1a&.eolymp.discussion.DeleteMessageOutput\"M\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\x82\xd3\xe4\x93\x02\x18*\x16/messages/{message_id}\x12\xac\x01\n\x0bVoteMessage\x12#.eolymp.discussion.VoteMessageInput\x1a$.eolymp.discussion.VoteMessageOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x02\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\x82\xd3\xe4\x93\x02\x1d\"\x1b/messages/{message_id}/vote\x12\xc3\x01\n\x12ListMessageChanges\x12*.eolymp.discussion.ListMessageChangesInput\x1a+.eolymp.discussion.ListMessageChangesOutput\"T\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x1b\x8a\xe3\n\x17\x64iscussion:message:read\x82\xd3\xe4\x93\x02 \x12\x1e/messages/{message_id}/changes\x1a\x33\x82\xf0\xf0\xe4\x01\x14\x65olymp.atlas.Problem\x82\xf0\xf0\xe4\x01\x13\x65olymp.content.PostB7Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.thread_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _globals['_THREADSERVICE']._loaded_options = None
  _globals['_THREADSERVICE']._serialized_options = b'\202\360\360\344\001\024eolymp.atlas.Problem\202\360\360\344\001\023eolymp.content.Post'
  _globals['_THREADSERVICE'].methods_by_name['DescribeThread']._loaded_options = None
  _globals['_THREADSERVICE'].methods_by_name['DescribeThread']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\t\022\007/thread'
  _globals['_THREADSERVICE'].methods_by_name['VoteThread']._loaded_options = None
  _globals['_THREADSERVICE'].methods_by_name['VoteThread']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\016\"\014/thread/vote'
  _globals['_THREADSERVICE'].methods_by_name['UpdateSubscription']._loaded_options = None
  _globals['_THREADSERVICE'].methods_by_name['UpdateSubscription']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n!\212\343\n\035discussion:subscription:write\202\323\344\223\002\026\032\024/thread/subscription'
  _globals['_THREADSERVICE'].methods_by_name['DescribeMessage']._loaded_options = None
  _globals['_THREADSERVICE'].methods_by_name['DescribeMessage']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\343\n\033\212\343\n\027discussion:message:read\202\323\344\223\002\037\022\035/thread/messages/{message_id}'
  _globals['_THREADSERVICE'].methods_by_name['ListMessages']._loaded_options = None
  _globals['_THREADSERVICE'].methods_by_name['ListMessages']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\033\212\343\n\027discussion:message:read\202\323\344\223\002\022\022\020/thread/messages'
  _globals['_THREADSERVICE'].methods_by_name['PostMessage']._loaded_options = None
  _globals['_THREADSERVICE'].methods_by_name['PostMessage']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\002\202\343\n\034\212\343\n\030discussion:message:write\202\323\344\223\002\022\"\020/thread/messages'
  _globals['_THREADSERVICE'].methods_by_name['UpdateMessage']._loaded_options = None
  _globals['_THREADSERVICE'].methods_by_name['UpdateMessage']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\002\202\343\n\034\212\343\n\030discussion:message:write\202\323\344\223\002\037\032\035/thread/messages/{message_id}'
  _globals['_THREADSERVICE'].methods_by_name['DeleteMessage']._loaded_options = None
  _globals['_THREADSERVICE'].methods_by_name['DeleteMessage']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\034\212\343\n\030discussion:message:write\202\323\344\223\002\030*\026/messages/{message_id}'
  _globals['_THREADSERVICE'].methods_by_name['VoteMessage']._loaded_options = None
  _globals['_THREADSERVICE'].methods_by_name['VoteMessage']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\002\202\343\n\034\212\343\n\030discussion:message:write\202\323\344\223\002\035\"\033/messages/{message_id}/vote'
  _globals['_THREADSERVICE'].methods_by_name['ListMessageChanges']._loaded_options = None
  _globals['_THREADSERVICE'].methods_by_name['ListMessageChanges']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\033\212\343\n\027discussion:message:read\202\323\344\223\002 \022\036/messages/{message_id}/changes'
  _globals['_DESCRIBETHREADINPUT']._serialized_start=315
  _globals['_DESCRIBETHREADINPUT']._serialized_end=352
  _globals['_DESCRIBETHREADOUTPUT']._serialized_start=354
  _globals['_DESCRIBETHREADOUTPUT']._serialized_end=419
  _globals['_VOTETHREADINPUT']._serialized_start=421
  _globals['_VOTETHREADINPUT']._serialized_end=472
  _globals['_VOTETHREADOUTPUT']._serialized_start=474
  _globals['_VOTETHREADOUTPUT']._serialized_end=512
  _globals['_THREADSERVICE']._serialized_start=515
  _globals['_THREADSERVICE']._serialized_end=2284
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/auth/certificate.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/auth/certificate.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/auth/certificate.proto\x12\x0b\x65olymp.auth\"\xa0\x01\n\x0b\x43\x65rtificate\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03use\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x11\n\talgorithm\x18\x04 \x01(\t\x12\x14\n\x0crsa_exponent\x18\n \x01(\t\x12\x13\n\x0brsa_modulus\x18\x0b \x01(\t\x12\x10\n\x08\x65\x63_curve\x18\x14 \x01(\t\x12\x0c\n\x04\x65\x63_x\x18\x15 \x01(\t\x12\x0c\n\x04\x65\x63_y\x18\x16 \x01(\tB+Z)github.com/eolymp/go-sdk/eolymp/auth;authb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.auth.certificate_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/eolymp/go-sdk/eolymp/auth;auth'
  _globals['_CERTIFICATE']._serialized_start=47
  _globals['_CERTIFICATE']._serialized_end=207
# @@protoc_insertion_point(module_scope)



import datetime

from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.auth import certificate_pb2 as _certificate_pb2
from eolymp.auth import claims_pb2 as _claims_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class IssueTokenInput(_message.Message):
    __slots__ = ("grant_type", "username", "password", "client_id", "client_secret", "code", "code_verifier", "scope", "refresh_token", "redirect_uri")
    class GrantType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NONE: _ClassVar[IssueTokenInput.GrantType]
        PASSWORD: _ClassVar[IssueTokenInput.GrantType]
        AUTHORIZATION_CODE: _ClassVar[IssueTokenInput.GrantType]
        REFRESH_TOKEN: _ClassVar[IssueTokenInput.GrantType]
        EOLYMP_SIGNIN: _ClassVar[IssueTokenInput.GrantType]
    NONE: IssueTokenInput.GrantType
    PASSWORD: IssueTokenInput.GrantType
    AUTHORIZATION_CODE: IssueTokenInput.GrantType
    REFRESH_TOKEN: IssueTokenInput.GrantType
    EOLYMP_SIGNIN: IssueTokenInput.GrantType
    GRANT_TYPE_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_SECRET_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    CODE_VERIFIER_FIELD_NUMBER: _ClassVar[int]
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_URI_FIELD_NUMBER: _ClassVar[int]
    grant_type: IssueTokenInput.GrantType
    username: str
    password: str
    client_id: str
    client_secret: str
    code: str
    code_verifier: str
    scope: str
    refresh_token: str
    redirect_uri: str
    def __init__(self, grant_type: _Optional[_Union[IssueTokenInput.GrantType, str]] = ..., username: _Optional[str] = ..., password: _Optional[str] = ..., client_id: _Optional[str] = ..., client_secret: _Optional[str] = ..., code: _Optional[str] = ..., code_verifier: _Optional[str] = ..., scope: _Optional[str] = ..., refresh_token: _Optional[str] = ..., redirect_uri: _Optional[str] = ...) -> None: ...

class IssueTokenOutput(_message.Message):
    __slots__ = ("access_token", "token_type", "expires_in", "refresh_token", "scope", "claims", "id_token")
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOKEN_TYPE_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_IN_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    CLAIMS_FIELD_NUMBER: _ClassVar[int]
    ID_TOKEN_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    token_type: str
    expires_in: int
    refresh_token: str
    scope: str
    claims: _claims_pb2.Claims
    id_token: str
    def __init__(self, access_token: _Optional[str] = ..., token_type: _Optional[str] = ..., expires_in: _Optional[int] = ..., refresh_token: _Optional[str] = ..., scope: _Optional[str] = ..., claims: _Optional[_Union[_claims_pb2.Claims, _Mapping]] = ..., id_token: _Optional[str] = ...) -> None: ...

class IntrospectTokenInput(_message.Message):
    __slots__ = ("token",)
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    token: str
    def __init__(self, token: _Optional[str] = ...) -> None: ...

class IntrospectTokenOutput(_message.Message):
    __slots__ = ("active", "scope", "expire", "claims")
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    EXPIRE_FIELD_NUMBER: _ClassVar[int]
    CLAIMS_FIELD_NUMBER: _ClassVar[int]
    active: bool
    scope: str
    expire: _timestamp_pb2.Timestamp
    claims: _claims_pb2.Claims
    def __init__(self, active: bool = ..., scope: _Optional[str] = ..., expire: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., claims: _Optional[_Union[_claims_pb2.Claims, _Mapping]] = ...) -> None: ...

class RevokeTokenInput(_message.Message):
    __slots__ = ("token",)
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    token: str
    def __init__(self, token: _Optional[str] = ...) -> None: ...

class RevokeTokenOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RequestAuthInput(_message.Message):
    __slots__ = ("client_id", "code_challenge", "code_challenge_method", "redirect_uri", "response_type", "scope", "state")
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CODE_CHALLENGE_FIELD_NUMBER: _ClassVar[int]
    CODE_CHALLENGE_METHOD_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_URI_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_TYPE_FIELD_NUMBER: _ClassVar[int]
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    code_challenge: str
    code_challenge_method: str
    redirect_uri: str
    response_type: str
    scope: str
    state: str
    def __init__(self, client_id: _Optional[str] = ..., code_challenge: _Optional[str] = ..., code_challenge_method: _Optional[str] = ..., redirect_uri: _Optional[str] = ..., response_type: _Optional[str] = ..., scope: _Optional[str] = ..., state: _Optional[str] = ...) -> None: ...

class RequestAuthOutput(_message.Message):
    __slots__ = ("authorization_code", "redirect_uri")
    AUTHORIZATION_CODE_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_URI_FIELD_NUMBER: _ClassVar[int]
    authorization_code: str
    redirect_uri: str
    def __init__(self, authorization_code: _Optional[str] = ..., redirect_uri: _Optional[str] = ...) -> None: ...

class UserInfoInput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UserInfoOutput(_message.Message):
    __slots__ = ("claims",)
    CLAIMS_FIELD_NUMBER: _ClassVar[int]
    claims: _claims_pb2.Claims
    def __init__(self, claims: _Optional[_Union[_claims_pb2.Claims, _Mapping]] = ...) -> None: ...

class ListCertificatesInput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListCertificatesOutput(_message.Message):
    __slots__ = ("items",)
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_certificate_pb2.Certificate]
    def __init__(self, items: _Optional[_Iterable[_Union[_certificate_pb2.Certificate, _Mapping]]] = ...) -> None: ...

class RegisterClientInput(_message.Message):
    __slots__ = ("redirect_uris", "token_endpoint_auth_method", "grant_types", "response_types", "client_name", "client_uri", "logo_uri", "scope", "contacts", "tos_uri", "policy_uri", "jwks_uri", "software_id", "software_version", "software_statement")
    REDIRECT_URIS_FIELD_NUMBER: _ClassVar[int]
    TOKEN_ENDPOINT_AUTH_METHOD_FIELD_NUMBER: _ClassVar[int]
    GRANT_TYPES_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_TYPES_FIELD_NUMBER: _ClassVar[int]
    CLIENT_NAME_FIELD_NUMBER: _ClassVar[int]
    CLIENT_URI_FIELD_NUMBER: _ClassVar[int]
    LOGO_URI_FIELD_NUMBER: _ClassVar[int]
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    CONTACTS_FIELD_NUMBER: _ClassVar[int]
    TOS_URI_FIELD_NUMBER: _ClassVar[int]
    POLICY_URI_FIELD_NUMBER: _ClassVar[int]
    JWKS_URI_FIELD_NUMBER: _ClassVar[int]
    SOFTWARE_ID_FIELD_NUMBER: _ClassVar[int]
    SOFTWARE_VERSION_FIELD_NUMBER: _ClassVar[int]
    SOFTWARE_STATEMENT_FIELD_NUMBER: _ClassVar[int]
    redirect_uris: _containers.RepeatedScalarFieldContainer[str]
    token_endpoint_auth_method: str
    grant_types: _containers.RepeatedScalarFieldContainer[str]
    response_types: _containers.RepeatedScalarFieldContainer[str]
    client_name: str
    client_uri: str
    logo_uri: str
    scope: str
    contacts: _containers.RepeatedScalarFieldContainer[str]
    tos_uri: str
    policy_uri: str
    jwks_uri: str
    software_id: str
    software_version: str
    software_statement: str
    def __init__(self, redirect_uris: _Optional[_Iterable[str]] = ..., token_endpoint_auth_method: _Optional[str] = ..., grant_types: _Optional[_Iterable[str]] = ..., response_types: _Optional[_Iterable[str]] = ..., client_name: _Optional[str] = ..., client_uri: _Optional[str] = ..., logo_uri: _Optional[str] = ..., scope: _Optional[str] = ..., contacts: _Optional[_Iterable[str]] = ..., tos_uri: _Optional[str] = ..., policy_uri: _Optional[str] = ..., jwks_uri: _Optional[str] = ..., software_id: _Optional[str] = ..., software_version: _Optional[str] = ..., software_statement: _Optional[str] = ...) -> None: ...

class RegisterClientOutput(_message.Message):
    __slots__ = ("client_id", "client_secret", "client_id_issued_at", "client_secret_expires_at", "registration_access_token", "registration_client_uri", "token_endpoint_auth_method", "application_type", "redirect_uris", "client_name", "logo_uri", "subject_type", "sector_identifier_uri", "jwks_uri", "userinfo_encrypted_response_alg", "userinfo_encrypted_response_enc", "contacts", "request_uris")
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_SECRET_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_ISSUED_AT_FIELD_NUMBER: _ClassVar[int]
    CLIENT_SECRET_EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    REGISTRATION_ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    REGISTRATION_CLIENT_URI_FIELD_NUMBER: _ClassVar[int]
    TOKEN_ENDPOINT_AUTH_METHOD_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_TYPE_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_URIS_FIELD_NUMBER: _ClassVar[int]
    CLIENT_NAME_FIELD_NUMBER: _ClassVar[int]
    LOGO_URI_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_TYPE_FIELD_NUMBER: _ClassVar[int]
    SECTOR_IDENTIFIER_URI_FIELD_NUMBER: _ClassVar[int]
    JWKS_URI_FIELD_NUMBER: _ClassVar[int]
    USERINFO_ENCRYPTED_RESPONSE_ALG_FIELD_NUMBER: _ClassVar[int]
    USERINFO_ENCRYPTED_RESPONSE_ENC_FIELD_NUMBER: _ClassVar[int]
    CONTACTS_FIELD_NUMBER: _ClassVar[int]
    REQUEST_URIS_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    client_secret: str
    client_id_issued_at: _timestamp_pb2.Timestamp
    client_secret_expires_at: _timestamp_pb2.Timestamp
    registration_access_token: str
    registration_client_uri: str
    token_endpoint_auth_method: str
    application_type: str
    redirect_uris: _containers.RepeatedScalarFieldContainer[str]
    client_name: str
    logo_uri: str
    subject_type: str
    sector_identifier_uri: str
    jwks_uri: str
    userinfo_encrypted_response_alg: str
    userinfo_encrypted_response_enc: str
    contacts: _containers.RepeatedScalarFieldContainer[str]
    request_uris: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, client_id: _Optional[str] = ..., client_secret: _Optional[str] = ..., client_id_issued_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., client_secret_expires_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., registration_access_token: _Optional[str] = ..., registration_client_uri: _Optional[str] = ..., token_endpoint_auth_method: _Optional[str] = ..., application_type: _Optional[str] = ..., redirect_uris: _Optional[_Iterable[str]] = ..., client_name: _Optional[str] = ..., logo_uri: _Optional[str] = ..., subject_type: _Optional[str] = ..., sector_identifier_uri: _Optional[str] = ..., jwks_uri: _Optional[str] = ..., userinfo_encrypted_response_alg: _Optional[str] = ..., userinfo_encrypted_response_enc: _Optional[str] = ..., contacts: _Optional[_Iterable[str]] = ..., request_uris: _Optional[_Iterable[str]] = ...) -> None: ...



from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor
MCP_TOOL_FIELD_NUMBER: _ClassVar[int]
mcp_tool: _descriptor.FieldDescriptor
MCP_VALUE_DESC_FIELD_NUMBER: _ClassVar[int]
mcp_value_desc: _descriptor.FieldDescriptor
MCP_FIELD_DESC_FIELD_NUMBER: _ClassVar[int]
mcp_field_desc: _descriptor.FieldDescriptor
READ_ONLY_FIELD_NUMBER: _ClassVar[int]
read_only: _descriptor.FieldDescriptor

class MCP(_message.Message):
    __slots__ = ()
    class Tool(_message.Message):
        __slots__ = ("name", "description", "require_confirmation")
        NAME_FIELD_NUMBER: _ClassVar[int]
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        REQUIRE_CONFIRMATION_FIELD_NUMBER: _ClassVar[int]
        name: str
        description: str
        require_confirmation: bool
        def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., require_confirmation: bool = ...) -> None: ...
    def __init__(self) -> None: ...
